##########
pex_config
##########

.. image:: https://img.shields.io/pypi/v/lsst-pex-config.svg
    :target: https://pypi.org/project/lsst-pex-config/
.. image:: https://codecov.io/gh/lsst/pex_config/branch/main/graph/badge.svg?token=QMTDkaVE1Y
    :target: https://codecov.io/gh/lsst/pex_config

``pex_config`` is a package in the `LSST Science Pipelines <https://pipelines.lsst.io>`_.
The ``lsst.pex.config`` module provides a configuration system that is integral to the task framework, though it can be used on its own as well.

* Documentation: https://pipelines.lsst.io/v/daily/modules/lsst.pex.config/
* SPIE paper from 2022: `The Vera C. Rubin Observatory Data Butler and Pipeline Execution System <https://arxiv.org/abs/2206.14941>`_.

PyPI: `lsst-pex-config <https://pypi.org/project/lsst-pex-config/>`_

This software is dual licensed under the GNU General Public License (version 3 of the License, or (at your option) any later version, and also under a 3-clause BSD license.
Recipients may choose which of these licenses to use; please see the files gpl-3.0.txt and/or bsd_license.txt, respectively.
